const {Message} = require('discord.js')
const mongoose = require('mongoose')
const chatbotSchema = require("./models/chatbot-schema")

class shevdev {
   /**
   * @name shevdev Class name
   * @param {Object} extra Object to set
   * @param {String} [extra.mongoDB] Connecting to MongoDB
   */
	constructor(extra) {
		if (mongoose.connection.readyState !== 1) {
			if (!extra.mongoDB)
				throw new TypeError(`You did not provide a path to connect to MongoDB`)
			mongoose.connect(extra.mongoDB);
			console.log('shevdev > MongoDB connection successfully')
		}
	}

	/**
	 * @method Add new sentences to database
	 * @param {String} guildID
	 * @param {Message} message
	 */
	static async updateAI(guildID, message) {
		if (!guildID) throw new Error('"guildID" is not defined')
		if (!message) throw new Error('"message" is not defined')

		const chatbotDB = await chatbotSchema.findOne({guildID: guildID});

		if (!chatbotDB) {
			new chatbotSchema({
				guildID: guildID,
				chatWords: ['Мой интеллект слишком слаб для этого сообщества. Общайтесь чаще!']
			}).save().catch(err => console.log(err.stack))
			return console.warn('shevdev > A database has been created for your server. Good luck!')
		}

		if (chatbotDB?.chatWords.includes(message)) return

		chatbotDB.chatWords.push(message)
		await chatbotDB.save().catch(err => console.log(err));

	}

	/**
	* @method Generate random message from database
	* @param {String} guildID
	* @param {Message} message
	*/
	static async chatbot(guildID, message) {
		if (message.author.bot) return
		if (!guildID) throw  new Error('"guildID" is not defined')
		if (!message) throw new Error('"message" is not defined')

		const chatbotDB = await chatbotSchema.findOne({guildID: guildID})

		const random = chatbotDB.chatWords[Math.floor(Math.random() * chatbotDB.chatWords.length)]
		return message.reply(random)
	}
}

module.exports = shevdev